pygeodesy.units.Band

Package pygeodesy :: Module units :: Class Band |
[frames] | no frames]

# Class Band

          object --+
                   |
          basestring --+
                       |
                     str --+
                           |
          object --+       |
                   |       |
        named._Named --+   |
                       |   |
    unitsBase._NamedUnit --+
                           |
               unitsBase.Str --+
                               |
                              Band

Named `str` representing a UTM/UPS band letter, unchecked.

Instance Methods
Inherited from `unitsBase.Str`: `__call__`, `__repr__`, `__str__`, `join_`, `toRepr`, `toStr` Inherited from `str`: `__add__`, `__contains__`, `__eq__`, `__format__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__hash__`, `__le__`, `__len__`, `__lt__`, `__mod__`, `__mul__`, `__ne__`, `__rmod__`, `__rmul__`, `__sizeof__`, `capitalize`, `center`, `count`, `decode`, `encode`, `endswith`, `expandtabs`, `find`, `format`, `index`, `isalnum`, `isalpha`, `isdigit`, `islower`, `isspace`, `istitle`, `isupper`, `join`, `ljust`, `lower`, `lstrip`, `partition`, `replace`, `rfind`, `rindex`, `rjust`, `rpartition`, `rsplit`, `rstrip`, `split`, `splitlines`, `startswith`, `strip`, `swapcase`, `title`, `translate`, `upper`, `zfill` Inherited from `named._Named`: `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, arg=None, name=`'``band``'`, **Error_name_arg) New, named Band, see Str. |

Properties
Inherited from `unitsBase._NamedUnit`: `std_repr`, `units` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, arg=None, name=`'``band``'`, **Error_name_arg) Static Method |
New, named Band, see Str. Arguments: `cls` - This class (`Str` or sub-class). `arg` - The value (any `type` acceptable to `str`). `name` - Optional name (`str`). `Error_name_arg` - Optional `Error=UnitError` to raise and optional `name=arg` keyword argument, inlieu of separate `arg` and `name` ones. Returns: a new object with type S, a subtype of T A named Str. Raises: `Error` - Invalid `arg`. Overrides: object.__new__